(function ($, Drupal) {
  // Define the behavior
  Drupal.behaviors.mediaLibraryTranslate = {
    attach(context, settings) {
      // Use noConflict to avoid conflicts with other libraries
      const $ = jQuery.noConflict();

      // Now you can use $ within this scope
      $(context).ready(function () {
        // Attach click event to the anchor tag with class "media-library-translate__link"
        const anchorTag = $('.media-library-translate__link', context);

        anchorTag.on('click', function () {
          // Attach AJAX success event listener
          $(document).ajaxSuccess(function (event, xhr, settings) {
            // Check if the opened modal contains an element with class "media-library-translate__modal"
            const modalContent = $('.media-library-translate__modal', context);

            if (modalContent.length) {
              // Select all anchor tags within the modal that are wrapped in specified <li> elements
              const anchorTags = modalContent.find('li.dropbutton-action a');

              // Add attributes and query parameter to each selected anchor tag
              anchorTags.each(function () {
                const anchor = $(this);
                anchor.attr('target', '_blank');

                // Get the current href value
                const href = anchor.attr('href');

                // Extract the path from the current window location
                const currentPath = window.location.pathname;

                // Add the Drupal query parameter to the href
                const updatedHref = addQueryParam(
                  href,
                  'destination',
                  currentPath,
                );

                // Update the href attribute with the new value
                anchor.attr('href', updatedHref);
              });
            } else {
              // Do nothing.
            }
          });
        });

        // Function to add a query parameter to a URL
        function addQueryParam(url, key, value) {
          const separator = url.indexOf('?') !== -1 ? '&' : '?';
          return `${
            url + separator + encodeURIComponent(key)
          }=${encodeURIComponent(value)}`;
        }
      });
    },
  };
})(jQuery, Drupal);
